@@ -125,14 +125,14 @@ class UnassignedVarWrapper(ast.NodeTransformer):
                 if isinstance(curr.parent, ast.If):
                     idx = curr.parent.orelse.index(curr)
                     is_else = True
-                else:
+                else: # pragma: no cover
                     raise
 
             curr = curr.parent
-            new_assign = ast.Assign([ast.Name(vn, ctx=ast.Load())], node, ctx=ast.Load())
+            new_assign = ast.Assign([ast.Name(vn, ast.Store())], node)
             new_assign.parent = curr
 
-            new_name = ast.Name(vn, ctx=ast.Load())
+            new_name = ast.Name(vn, ast.Load())
             new_name.parent = node.parent
             node.parent = new_assign
 
