@@ -42,6 +42,8 @@ def test_notebook_execution():
             with mock.patch("pybryt.execution.mkstemp") as mocked_tempfile:
                 mocked_tempfile.return_value = (None, observed_ntf.name)
 
-                n_steps, observed = execute_notebook(nb, "", output=ntf.name)
+                n_steps, observed, calls, _ = execute_notebook(nb, "", output=ntf.name)
                 assert len(ntf.read()) > 0
                 assert n_steps == max(t[1] for t in observed)
+                assert isinstance(calls, list) and isinstance(calls[0], tuple) and \
+                    isinstance(calls[0][0], str) and isinstance(calls[0][1], str)
